pub const unsafe fn encode() -> EncodedX86_64InstructionExpand description
Fast call to privilege level 0 system procedures.
Safety
This function is safe to call. It is marked as unsafe for consistency with other encoders.
pub const unsafe fn encode() -> EncodedX86_64InstructionFast call to privilege level 0 system procedures.
This function is safe to call. It is marked as unsafe for consistency with other encoders.